@@ -17,6 +17,7 @@ import wcmatch.pathlib
 import wcmatch.wcmatch
 from yaml.error import YAMLError
 
+from ansiblelint.app import get_app
 from ansiblelint.config import ANSIBLE_OWNED_KINDS, BASE_KINDS, Options, options
 from ansiblelint.constants import CONFIG_FILENAMES, FileType, States
 
@@ -182,7 +183,7 @@ class Lintable:
     When symlinks are given, they will always be resolved to their target.
     """
 
-    # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-arguments,too-many-positional-arguments
     def __init__(
         self,
         name: str | Path,
@@ -226,14 +227,22 @@ class Lintable:
         parts = self.path.parent.parts
         if "roles" in parts:
             role = self.path
-            while role.parent.name != "roles" and role.name:
+            roles_path = get_app(cached=True).runtime.config.default_roles_path
+            while (
+                str(role.parent.absolute()) not in roles_path
+                and role.parent.name != "roles"
+                and role.name
+            ):
                 role = role.parent
             if role.exists():
                 self.role = role.name
 
         if str(self.path) in ["/dev/stdin", "-"]:
             # pylint: disable=consider-using-with
-            self.file = NamedTemporaryFile(mode="w+", suffix="playbook.yml")
+            self.file = NamedTemporaryFile(  # noqa: SIM115
+                mode="w+",
+                suffix="playbook.yml",
+            )
             self.filename = self.file.name
             self._content = sys.stdin.read()
             self.file.write(self._content)
@@ -424,7 +433,11 @@ class Lintable:
                         # pylint: disable=import-outside-toplevel
                         from ansiblelint.skip_utils import append_skipped_rules
 
-                    self.state = append_skipped_rules(self.state, self)
+                    # pylint: disable=possibly-used-before-assignment
+                    self.state = append_skipped_rules(
+                        self.state,
+                        self,
+                    )
                 else:
                     logging.debug(
                         "data set to None for %s due to being '%s' (%s) kind.",
